%
% Elastic wave extrapolation IR
% via elastic 1W
%
% Factorization of the full elastic isotropic wave equation
% (for displacement components)
%
% Musa Maharramov, Stanford, May 2012
% plotting modules Nov, 2012
%
clc;
%
nx=str2num(getenv('OWE_NX'));
ny=str2num(getenv('OWE_NY'));
nz=str2num(getenv('OWE_NZ'));
%
dx=str2num(getenv('OWE_DX'));
dy=str2num(getenv('OWE_DY'));
dz=str2num(getenv('OWE_DZ'));
%
image=zeros(3,nz,nx,ny);
pressure=zeros(nz,nx,ny);
image1=image;
%
% read all frequencies inro a string 
str_freq=[getenv('OWE_FREQ_GROUP_1')...
 ' ' getenv('OWE_FREQ_GROUP_2')];
% split into individual frequency strings
wtext=strread(str_freq,'%s','delimiter',' ');
% read the image files for each frequency
for i=1:size(wtext,1)
  w=str2num(wtext{i})*2*pi;
  fname=[num2str(w) '_' num2str(w) 'img.bin'];
  fid = fopen(fname, 'r');
  img=fread(fid, 'double');
  image1=reshape(img,3,nz,nx,ny);
  image=image+image1;
  fclose(fid);
end
%
% spectral plots (for max freq only)
for i=size(wtext,1):size(wtext,1)
  w=str2num(wtext{i})*2*pi;
%
  fname=[num2str(w) '_' num2str(w) 'Arspec.bin'];
  fid = fopen(fname, 'r');
  spec=fread(fid, 'double');
  Arphase_spectrum=reshape(spec, 3, nx, ny);
  fclose(fid);
%
  fname=[num2str(w) '_' num2str(w) 'Aispec.bin'];
  fid = fopen(fname, 'r');
  spec=fread(fid, 'double');
  Aiphase_spectrum=reshape(spec, 3, nx, ny);
  fclose(fid);
%
  fname=[num2str(w) '_' num2str(w) 'Brspec.bin'];
  fid = fopen(fname, 'r');
  spec=fread(fid, 'double');
  Brphase_spectrum=reshape(spec, 3, nx, ny);
  fclose(fid);
%
  fname=[num2str(w) '_' num2str(w) 'Bispec.bin'];
  fid = fopen(fname, 'r');
  spec=fread(fid, 'double');
  Biphase_spectrum=reshape(spec, 3, nx, ny);
  fclose(fid);
% 
  Z=zeros(nx,ny);
  for j=1:3
   figure
    Z(:,:)=Arphase_spectrum(j,:,:);
    surf (Z, 'EdgeColor','none');
    colormap(gray);
    colorbar;
    view(180,90);
    xlabel('kx','fontsize',12,'fontweight','b','color','k');
    ylabel('ky','fontsize',12,'fontweight','b','color','k');
    title(['Re EIG(' num2str(j) ') A, freq ' wtext{i}],'FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', ['EIG_A_' num2str(j)...
     '_real_' num2str(w) '.pdf']);

   figure
    Z(:,:)=Aiphase_spectrum(j,:,:);
    surf (Z, 'EdgeColor','none');
    colormap(gray);
    colorbar;
    view(180,90);
    xlabel('kx','fontsize',12,'fontweight','b','color','k');
    ylabel('ky','fontsize',12,'fontweight','b','color','k');
    title(['Im EIG(' num2str(j) ') A, freq ' wtext{i}],'FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', ['EIG_A_' num2str(j)...
     '_imag_' num2str(w) '.pdf']);
%
   figure
    Z(:,:)=Brphase_spectrum(j,:,:);
    surf (Z, 'EdgeColor','none');
    colormap(gray);
    colorbar;
    view(180,90);
    xlabel('kx','fontsize',12,'fontweight','b','color','k');
    ylabel('ky','fontsize',12,'fontweight','b','color','k');
    title(['Re EIG(' num2str(j) ') B, freq ' wtext{i}],'FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', ['EIG_B_' num2str(j)...
     '_real_' num2str(w) '.pdf']);
%
   figure
    Z(:,:)=Biphase_spectrum(j,:,:);
    surf (Z, 'EdgeColor','none');
    colormap(gray);
    colorbar;
    view(180,90);
    xlabel('kx','fontsize',12,'fontweight','b','color','k');
    ylabel('ky','fontsize',12,'fontweight','b','color','k');
    title(['Im EIG(' num2str(j) ') B, freq ' wtext{i}],'FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', ['EIG_B_' num2str(j)...
     '_imag_' num2str(w) '.pdf']);
  end
end

% pressure field
for iz=1:nz
    for iy=1:ny
      for ix=1:nx
        if (ix==1)
          pressure(iz,ix,iy)=pressure(iz,ix,iy)+(image(1,iz,ix+1,iy)-image(1,iz,ix,iy))/dx;
        elseif (ix==nx)
          pressure(iz,ix,iy)=pressure(iz,ix,iy)+(image(1,iz,ix,iy)-image(1,iz,ix-1,iy))/dx;
        else
          pressure(iz,ix,iy)=pressure(iz,ix,iy)+(image(1,iz,ix+1,iy)-image(1,iz,ix-1,iy))/(2*dx);
        end
        if (iy==1)
          pressure(iz,ix,iy)=pressure(iz,ix,iy)+(image(2,iz,ix,iy+1)-image(2,iz,ix,iy))/dy;
        elseif (iy==ny)
          pressure(iz,ix,iy)=pressure(iz,ix,iy)+(image(2,iz,ix,iy)-image(2,iz,ix,iy-1))/dy;
        else
          pressure(iz,ix,iy)=pressure(iz,ix,iy)+(image(2,iz,ix,iy+1)-image(2,iz,ix,iy-1))/(2*dy);          
        end
        if (iz==1)
          pressure(iz,ix,iy)=pressure(iz,ix,iy)+(image(3,iz+1,ix,iy)-image(3,iz,ix,iy))/dz;
        elseif (iz==nz)
          pressure(iz,ix,iy)=pressure(iz,ix,iy)+(image(3,iz,ix,iy)-image(3,iz-1,ix,iy))/dz;
        else
          pressure(iz,ix,iy)=pressure(iz,ix,iy)+(image(3,iz+1,ix,iy)-image(3,iz-1,ix,iy))/(2*dz);          
        end        
      end
    end
  end
  %
  section_y1=zeros(nz,nx);  
  section_y2=section_y1;section_y3=section_y1;
%
  section_x1=zeros(nz,ny);  
  section_x2=section_x1;section_x3=section_x1;
%
  pressure_section_y=section_y1;
  pressure_section_x=section_x1;
%
  for ix=1:nx
    for iz=1:nz
      section_y1(iz,ix)=real(image(1,iz,ix,ny/2));
      section_y2(iz,ix)=real(image(2,iz,ix,ny/2));
      section_y3(iz,ix)=real(image(3,iz,ix,ny/2));
      pressure_section_y(iz,ix)=real(pressure(iz,ix,ny/2));
    end
  end
  %
  for iy=1:ny
    for iz=1:nz
      section_x1(iz,iy)=real(image(1,iz,nx/2,iy));
      section_x2(iz,iy)=real(image(2,iz,nx/2,iy));
      section_x3(iz,iy)=real(image(3,iz,nx/2,iy));
      pressure_section_x(iz,iy)=real(pressure(iz,nx/2,iy));
    end
  end
  %
   figure
    surf (pressure_section_y, 'EdgeColor','none');
    colormap(gray);
    view(180,90);
    xlabel('Inline','fontsize',12,'fontweight','b','color','k');
    ylabel('Depth','fontsize',12,'fontweight','b','color','k');
    title('Pressure Wave - inline section','FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', 'pressure_const_y.pdf');

  figure
    surf (section_y1, 'EdgeColor','none');
    colormap(gray);
    view(180,90);
    xlabel('Inline','fontsize',12,'fontweight','b','color','k');
    ylabel('Depth','fontsize',12,'fontweight','b','color','k');
    title('Inline section of Inline Component','FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', 'dispx_const_y.pdf');

  figure
    surf (section_y2, 'EdgeColor','none');
    colormap(gray);
    view(180,90);
    xlabel('Inline','fontsize',12,'fontweight','b','color','k');
    ylabel('Depth','fontsize',12,'fontweight','b','color','k');
    title('Inline section of Crossline Component','FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', 'dispy_const_y.pdf');

  figure
    surf (section_y3, 'EdgeColor','none');
    colormap(gray);
    view(180,90);
    xlabel('Inline','fontsize',12,'fontweight','b','color','k');
    ylabel('Depth','fontsize',12,'fontweight','b','color','k');
    title('Inline section of Vertical Component','FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', 'dispz_const_y.pdf');
%
  %
   figure
    surf (pressure_section_x, 'EdgeColor','none');
    colormap(gray);
    view(180,90);
    xlabel('Crossline','fontsize',12,'fontweight','b','color','k');
    ylabel('Depth','fontsize',12,'fontweight','b','color','k');
    title('Pressure Wave - crossline','FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', 'pressure_const_x.pdf');

  figure
    surf (section_x1, 'EdgeColor','none');
    colormap(gray);
    view(180,90);
    xlabel('Crossline','fontsize',12,'fontweight','b','color','k');
    ylabel('Depth','fontsize',12,'fontweight','b','color','k');
    title('Crossline section of Inline Component','FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', 'dispx_const_x.pdf');

  figure
    surf (section_x2, 'EdgeColor','none');
    colormap(gray);
    view(180,90);
    xlabel('Crossline','fontsize',12,'fontweight','b','color','k');
    ylabel('Depth','fontsize',12,'fontweight','b','color','k');
    title('Crossline section of Crossline Component','FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', 'dispy_const_x.pdf');

  figure
    surf (section_x3, 'EdgeColor','none');
    colormap(gray);
    view(180,90);
    xlabel('Crossline','fontsize',12,'fontweight','b','color','k');
    ylabel('Depth','fontsize',12,'fontweight','b','color','k');
    title('Crossline section of Vertical Component','FontSize',12)
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperSize', [8 7]);
    set(gcf, 'PaperPositionMode', 'auto');
    print(gcf, '-dpdf', 'dispz_const_x.pdf');
